# [conv_lstm_pytorch](https://github.com/Jimexist/conv_lstm_pytorch)

[![PyPI](https://img.shields.io/pypi/v/conv-lstm?style=flat-square)](https://pypi.org/project/conv-lstm)

This version is forked and adapted from https://github.com/ndrplz/ConvLSTM_pytorch.

Original authors are:

- https://github.com/ndrplz/ConvLSTM_pytorch
- https://github.com/DavideA
- https://github.com/rogertrullo/pytorch_convlstm

Please checkout the code itself and unit tests for details usage and examples.

## Code style

This repo is managed by poetry, formatted by black, isort, and type checked by mypy.
